@@ -1,4 +1,4 @@
-Merge <- function(..., join="outer", fill=0, split=FALSE)
+Merge <- function(..., join="outer", fill=0, split=FALSE, verbose=TRUE)
 {
    d <- list(...)
    cnames <- unique(unlist(lapply(d, colnames)))
@@ -23,7 +23,7 @@ Merge <- function(..., join="outer", fill=0, split=FALSE)
       allnames <- unlist(lapply(d, colnames))
       t <- table(allnames)
       cnames <- names(t)[t==nd]
-      if (length(cnames)==0)
+      if (length(cnames)==0 & verbose)
          warning("One or more datasets have no varaibles in common.")
       cnames <- sort(cnames)
       x <- matrix(fill, nrow=nr, ncol=length(cnames))
@@ -31,7 +31,7 @@ Merge <- function(..., join="outer", fill=0, split=FALSE)
       for (i in 1:nd) {
         mt <- match(colnames(d[[i]]), cnames)
         mt2 <- na.omit(mt)
-        if (length(mt2) == 0)
+        if (length(mt2) == 0 & verbose)
            warning("One or more datasets have no variables in common.")
         nt <- (n+1):(n+dims[[i]][1])
         x[nt, mt2] <- as.matrix(d[[i]][, !is.na(mt)])
@@ -47,7 +47,7 @@ Merge <- function(..., join="outer", fill=0, split=FALSE)
      ord <- order(colnames(d[[1]]))
      mt <- match(colnames(d2), cnames)
      mt2 <- na.omit(mt)
-     if (length(mt2) == 0)
+     if (length(mt2) == 0 & verbose)
         warning("One or more datasets have no variables in common.")
      x <- matrix(fill, nrow=nr, ncol=length(cnames))
      x[1:dims[[1]][1], ] <- as.matrix(d[[1]][, ord])
@@ -56,7 +56,7 @@ Merge <- function(..., join="outer", fill=0, split=FALSE)
    x <- as.data.frame(x)
    colnames(x) <- cnames
    rownames(x) <- make.unique(rnames)
-   if (any(rownames(x) != rnames))
+   if (any(rownames(x) != rnames) & verbose)
       warning("Some row names were changed to avoid duplicates.")
    if (split) {
       l <- list(length(nd))
